# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workitems.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import ace_pb2 as ace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkitems.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\tace.proto\"\xaa\x03\n\x08workitem\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12+\n\x07nextrun\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07lastrun\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x05\x66iles\x18\x07 \x03(\x0b\x32\x15.openiap.workitemfile\x12\r\n\x05state\x18\x08 \x01(\t\x12\x0b\n\x03wiq\x18\t \x01(\t\x12\r\n\x05wiqid\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x10\n\x08username\x18\x0c \x01(\t\x12\x15\n\rsuccess_wiqid\x18\r \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x0e \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0f \x01(\t\x12\x12\n\nfailed_wiq\x18\x10 \x01(\t\x12\x14\n\x0c\x65rrormessage\x18\x11 \x01(\t\x12\x13\n\x0b\x65rrorsource\x18\x12 \x01(\t\x12\x11\n\terrortype\x18\x13 \x01(\t\"O\n\x0cworkitemfile\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03_id\x18\x02 \x01(\t\x12\x12\n\ncompressed\x18\x03 \x01(\x08\x12\x0c\n\x04\x66ile\x18\x04 \x01(\x0c\"\x84\x02\n\x0cpushworkitem\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\t\x12+\n\x07nextrun\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_wiqid\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x07 \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x08 \x01(\t\x12\x12\n\nfailed_wiq\x18\t \x01(\t\x12\x10\n\x08priority\x18\n \x01(\x05\x12$\n\x05\x66iles\x18\x0b \x03(\x0b\x32\x15.openiap.workitemfile\"8\n\x11pushworkitemreply\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\"\xe2\x01\n\rpushworkitems\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12+\n\x07nextrun\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_wiqid\x18\x04 \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x05 \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x06 \x01(\t\x12\x12\n\nfailed_wiq\x18\x07 \x01(\t\x12\x10\n\x08priority\x18\x08 \x01(\x05\x12 \n\x05items\x18\t \x03(\x0b\x32\x11.openiap.workitem\":\n\x12pushworkitemsreply\x12$\n\tworkitems\x18\x01 \x03(\x0b\x32\x11.openiap.workitem\"O\n\x0eupdateworkitem\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\x12\x18\n\x10ignoremaxretries\x18\x02 \x01(\x08\":\n\x13updateworkitemreply\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\"S\n\x0bpopworkitem\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12\x14\n\x0cincludefiles\x18\x03 \x01(\x08\x12\x12\n\ncompressed\x18\x04 \x01(\x08\"7\n\x10popworkitemreply\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\"\x1d\n\x0e\x64\x65leteworkitem\x12\x0b\n\x03_id\x18\x01 \x01(\t\"\x15\n\x13\x64\x65leteworkitemreply\"\x80\x04\n\rworkitemqueue\x12\x12\n\nworkflowid\x18\x01 \x01(\t\x12\x12\n\nrobotqueue\x18\x02 \x01(\t\x12\x11\n\tamqpqueue\x18\x03 \x01(\t\x12\x11\n\tprojectid\x18\x04 \x01(\t\x12\x11\n\tusersrole\x18\x05 \x01(\t\x12\x12\n\nmaxretries\x18\x06 \x01(\x05\x12\x12\n\nretrydelay\x18\x07 \x01(\x05\x12\x14\n\x0cinitialdelay\x18\x08 \x01(\x05\x12\x15\n\rsuccess_wiqid\x18\t \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\n \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0b \x01(\t\x12\x12\n\nfailed_wiq\x18\x0c \x01(\t\x12\x0b\n\x03_id\x18\r \x01(\t\x12\x1a\n\x04_acl\x18\x0e \x03(\x0b\x32\x0c.openiap.ace\x12\x0c\n\x04name\x18\x0f \x01(\t\x12\x14\n\x0c_createdbyid\x18\x10 \x01(\t\x12\x12\n\n_createdby\x18\x11 \x01(\t\x12,\n\x08_created\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\r_modifiedbyid\x18\x13 \x01(\t\x12\x13\n\x0b_modifiedby\x18\x14 \x01(\t\x12-\n\t_modified\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08_version\x18\x16 \x01(\x05\"\x9c\x02\n\x10\x61\x64\x64workitemqueue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nrobotqueue\x18\x02 \x01(\t\x12\x11\n\tamqpqueue\x18\x03 \x01(\t\x12\x11\n\tprojectid\x18\x04 \x01(\t\x12\x10\n\x08skiprole\x18\x05 \x01(\x08\x12\x12\n\nmaxretries\x18\x06 \x01(\x05\x12\x14\n\x0cinitialdelay\x18\x07 \x01(\x05\x12\x12\n\nretrydelay\x18\x08 \x01(\x05\x12\x15\n\rsuccess_wiqid\x18\t \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\n \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0b \x01(\t\x12\x12\n\nfailed_wiq\x18\x0c \x01(\t\x12\x1a\n\x04_acl\x18\r \x03(\x0b\x32\x0c.openiap.ace\"F\n\x15\x61\x64\x64workitemqueuereply\x12-\n\rworkitemqueue\x18\x01 \x01(\x0b\x32\x16.openiap.workitemqueueb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workitems_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKITEM._serialized_start=73
  _WORKITEM._serialized_end=499
  _WORKITEMFILE._serialized_start=501
  _WORKITEMFILE._serialized_end=580
  _PUSHWORKITEM._serialized_start=583
  _PUSHWORKITEM._serialized_end=843
  _PUSHWORKITEMREPLY._serialized_start=845
  _PUSHWORKITEMREPLY._serialized_end=901
  _PUSHWORKITEMS._serialized_start=904
  _PUSHWORKITEMS._serialized_end=1130
  _PUSHWORKITEMSREPLY._serialized_start=1132
  _PUSHWORKITEMSREPLY._serialized_end=1190
  _UPDATEWORKITEM._serialized_start=1192
  _UPDATEWORKITEM._serialized_end=1271
  _UPDATEWORKITEMREPLY._serialized_start=1273
  _UPDATEWORKITEMREPLY._serialized_end=1331
  _POPWORKITEM._serialized_start=1333
  _POPWORKITEM._serialized_end=1416
  _POPWORKITEMREPLY._serialized_start=1418
  _POPWORKITEMREPLY._serialized_end=1473
  _DELETEWORKITEM._serialized_start=1475
  _DELETEWORKITEM._serialized_end=1504
  _DELETEWORKITEMREPLY._serialized_start=1506
  _DELETEWORKITEMREPLY._serialized_end=1527
  _WORKITEMQUEUE._serialized_start=1530
  _WORKITEMQUEUE._serialized_end=2042
  _ADDWORKITEMQUEUE._serialized_start=2045
  _ADDWORKITEMQUEUE._serialized_end=2329
  _ADDWORKITEMQUEUEREPLY._serialized_start=2331
  _ADDWORKITEMQUEUEREPLY._serialized_end=2401
# @@protoc_insertion_point(module_scope)
