# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbase.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\xa6\x01\n\x08\x65nvelope\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x0b\n\x03seq\x18\x03 \x01(\x05\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0b\n\x03rid\x18\x06 \x01(\t\x12\x0f\n\x07traceid\x18\x07 \x01(\t\x12\x0e\n\x06spanid\x18\x08 \x01(\t\x12\"\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\"\x06\n\x04noop\"\x06\n\x04ping\"\x06\n\x04pong\"5\n\x05\x65rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\r\n\x05stack\x18\x03 \x01(\t\"\x1b\n\ngetelement\x12\r\n\x05xpath\x18\x01 \x01(\t\"\x15\n\x04send\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"(\n\x08\x64ownload\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\"?\n\rdownloadreply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x10\n\x08mimetype\x18\x03 \x01(\t\",\n\x06upload\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\"y\n\x0buploadreply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\r\n\x05\x62ytes\x18\x03 \x01(\x05\x12\x0e\n\x06\x63hunks\x18\x04 \x01(\x05\x12\n\n\x02mb\x18\x05 \x01(\x02\x12\x13\n\x0b\x65lapsedTime\x18\x06 \x01(\x05\x12\x0c\n\x04mbps\x18\x07 \x01(\x02\"\t\n\x07\x63onsole\"\x0f\n\rclientconsole\"<\n\x0b\x62\x65ginstream\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x1b\n\x04stat\x18\x02 \x01(\x0b\x32\r.openiap.stat\"\x16\n\x06stream\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x0b\n\tendstream\"\xa1\x02\n\x04stat\x12\x13\n\x0b\x62irthtimeMs\x18\x01 \x01(\x02\x12\x0f\n\x07\x62lksize\x18\x02 \x01(\x05\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x05\x12)\n\x05\x63time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63timeMs\x18\x05 \x01(\x02\x12\x0b\n\x03\x64\x65v\x18\x06 \x01(\x05\x12\x0b\n\x03gid\x18\x07 \x01(\x05\x12\x0b\n\x03ino\x18\x08 \x01(\x05\x12\x0c\n\x04mode\x18\t \x01(\x05\x12)\n\x05mtime\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07mtimeMs\x18\x0b \x01(\x02\x12\r\n\x05nlink\x18\x0c \x01(\x05\x12\x0c\n\x04rdev\x18\r \x01(\x05\x12\x0c\n\x04size\x18\x0e \x01(\x05\x12\x0b\n\x03uid\x18\x0f \x01(\x05\"H\n\rcustomcommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"$\n\x12\x63ustomcommandreply\x12\x0e\n\x06result\x18\x01 \x01(\t\"G\n\x06signin\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0b\n\x03jwt\x18\x03 \x01(\t\x12\x0c\n\x04ping\x18\x04 \x01(\x08\"7\n\x0bsigninreply\x12\x0b\n\x03jwt\x18\x01 \x01(\t\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.openiap.user\"J\n\x0crefreshtoken\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0b\n\x03jwt\x18\x02 \x01(\t\x12\x1b\n\x04user\x18\x03 \x01(\x0b\x32\r.openiap.user\"!\n\x04role\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x04user\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x1c\n\x05roles\x18\x05 \x03(\x0b\x32\r.openiap.role2y\n\x0bgrpcService\x12\x39\n\x0bSetupStream\x12\x11.openiap.envelope\x1a\x11.openiap.envelope\"\x00(\x01\x30\x01\x12/\n\x06Signin\x12\x0f.openiap.signin\x1a\x14.openiap.signinreplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVELOPE._serialized_start=84
  _ENVELOPE._serialized_end=250
  _NOOP._serialized_start=252
  _NOOP._serialized_end=258
  _PING._serialized_start=260
  _PING._serialized_end=266
  _PONG._serialized_start=268
  _PONG._serialized_end=274
  _ERROR._serialized_start=276
  _ERROR._serialized_end=329
  _GETELEMENT._serialized_start=331
  _GETELEMENT._serialized_end=358
  _SEND._serialized_start=360
  _SEND._serialized_end=381
  _DOWNLOAD._serialized_start=383
  _DOWNLOAD._serialized_end=423
  _DOWNLOADREPLY._serialized_start=425
  _DOWNLOADREPLY._serialized_end=488
  _UPLOAD._serialized_start=490
  _UPLOAD._serialized_end=534
  _UPLOADREPLY._serialized_start=536
  _UPLOADREPLY._serialized_end=657
  _CONSOLE._serialized_start=659
  _CONSOLE._serialized_end=668
  _CLIENTCONSOLE._serialized_start=670
  _CLIENTCONSOLE._serialized_end=685
  _BEGINSTREAM._serialized_start=687
  _BEGINSTREAM._serialized_end=747
  _STREAM._serialized_start=749
  _STREAM._serialized_end=771
  _ENDSTREAM._serialized_start=773
  _ENDSTREAM._serialized_end=784
  _STAT._serialized_start=787
  _STAT._serialized_end=1076
  _CUSTOMCOMMAND._serialized_start=1078
  _CUSTOMCOMMAND._serialized_end=1150
  _CUSTOMCOMMANDREPLY._serialized_start=1152
  _CUSTOMCOMMANDREPLY._serialized_end=1188
  _SIGNIN._serialized_start=1190
  _SIGNIN._serialized_end=1261
  _SIGNINREPLY._serialized_start=1263
  _SIGNINREPLY._serialized_end=1318
  _REFRESHTOKEN._serialized_start=1320
  _REFRESHTOKEN._serialized_end=1394
  _ROLE._serialized_start=1396
  _ROLE._serialized_end=1429
  _USER._serialized_start=1431
  _USER._serialized_end=1527
  _GRPCSERVICE._serialized_start=1529
  _GRPCSERVICE._serialized_end=1650
# @@protoc_insertion_point(module_scope)
