# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: queues.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cqueues.proto\x12\x07openiap\"\"\n\rregisterqueue\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\'\n\x12registerqueuereply\x12\x11\n\tqueuename\x18\x01 \x01(\t\"a\n\x10registerexchange\x12\x14\n\x0c\x65xchangename\x18\x01 \x01(\t\x12\x11\n\talgorithm\x18\x02 \x01(\t\x12\x12\n\nroutingkey\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64\x64queue\x18\x04 \x01(\x08\"*\n\x15registerexchangereply\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x95\x01\n\x0cqueuemessage\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\x12\x12\n\nstriptoken\x18\x07 \x01(\x08\"\x86\x01\n\x11queuemessagereply\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"\x7f\n\nqueueevent\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"$\n\x0funregisterqueue\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x16\n\x14unregisterqueuereplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'queues_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERQUEUE._serialized_start=25
  _REGISTERQUEUE._serialized_end=59
  _REGISTERQUEUEREPLY._serialized_start=61
  _REGISTERQUEUEREPLY._serialized_end=100
  _REGISTEREXCHANGE._serialized_start=102
  _REGISTEREXCHANGE._serialized_end=199
  _REGISTEREXCHANGEREPLY._serialized_start=201
  _REGISTEREXCHANGEREPLY._serialized_end=243
  _QUEUEMESSAGE._serialized_start=246
  _QUEUEMESSAGE._serialized_end=395
  _QUEUEMESSAGEREPLY._serialized_start=398
  _QUEUEMESSAGEREPLY._serialized_end=532
  _QUEUEEVENT._serialized_start=534
  _QUEUEEVENT._serialized_end=661
  _UNREGISTERQUEUE._serialized_start=663
  _UNREGISTERQUEUE._serialized_end=699
  _UNREGISTERQUEUEREPLY._serialized_start=701
  _UNREGISTERQUEUEREPLY._serialized_end=723
# @@protoc_insertion_point(module_scope)
