# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: querys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cquerys.proto\x12\x07openiap\"&\n\x0flistcollections\x12\x13\n\x0bincludehist\x18\x01 \x01(\x08\"\'\n\x14listcollectionsreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"(\n\x0e\x64ropcollection\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\"\x15\n\x13\x64ropcollectionreply\"\x7f\n\x05query\x12\r\n\x05query\x18\x01 \x01(\t\x12\x16\n\x0e\x63ollectionname\x18\x02 \x01(\t\x12\x12\n\nprojection\x18\x03 \x01(\t\x12\x0b\n\x03top\x18\x04 \x01(\x05\x12\x0c\n\x04skip\x18\x05 \x01(\x05\x12\x0f\n\x07orderby\x18\x06 \x01(\t\x12\x0f\n\x07queryas\x18\x07 \x01(\t\"\x1d\n\nqueryreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"Z\n\x12getdocumentversion\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65\x63rypt\x18\x04 \x01(\x08\")\n\x17getdocumentversionreply\x12\x0e\n\x06result\x18\x01 \x01(\t\"V\n\taggregate\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x12\n\naggregates\x18\x02 \x01(\t\x12\x0f\n\x07queryas\x18\x03 \x01(\t\x12\x0c\n\x04hint\x18\x04 \x01(\t\"!\n\x0e\x61ggregatereply\x12\x0f\n\x07results\x18\x01 \x01(\t\"?\n\x05\x63ount\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x0f\n\x07queryas\x18\x03 \x01(\t\"\x1c\n\ncountreply\x12\x0e\n\x06result\x18\x01 \x01(\x05\"G\n\tinsertone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\" \n\x0einsertonereply\x12\x0e\n\x06result\x18\x01 \x01(\t\"^\n\ninsertmany\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05items\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\x12\x13\n\x0bskipresults\x18\x05 \x01(\x08\"\"\n\x0finsertmanyreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"G\n\tupdateone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\" \n\x0eupdateonereply\x12\x0e\n\x06result\x18\x01 \x01(\t\"_\n\x0eupdatedocument\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\"|\n\x0cupdateresult\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x08\x12\x14\n\x0cmatchedCount\x18\x02 \x01(\x05\x12\x15\n\rmodifiedCount\x18\x03 \x01(\x05\x12\x15\n\rupsertedCount\x18\x04 \x01(\x05\x12\x12\n\nupsertedId\x18\x05 \x01(\t\">\n\x13updatedocumentreply\x12\'\n\x08opresult\x18\x01 \x01(\x0b\x32\x15.openiap.updateresult\"b\n\x11insertorupdateone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x11\n\tuniqeness\x18\x02 \x01(\t\x12\x0c\n\x04item\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\"(\n\x16insertorupdateonereply\x12\x0e\n\x06result\x18\x01 \x01(\t\"y\n\x12insertorupdatemany\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x11\n\tuniqeness\x18\x02 \x01(\t\x12\r\n\x05items\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\x12\x13\n\x0bskipresults\x18\x06 \x01(\x08\"*\n\x17insertorupdatemanyreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"B\n\tdeleteone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\"&\n\x0e\x64\x65leteonereply\x12\x14\n\x0c\x61\x66\x66\x65\x63tedrows\x18\x01 \x01(\x05\"S\n\ndeletemany\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x0b\n\x03ids\x18\x04 \x03(\t\"\'\n\x0f\x64\x65letemanyreply\x12\x14\n\x0c\x61\x66\x66\x65\x63tedrows\x18\x01 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'querys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LISTCOLLECTIONS._serialized_start=25
  _LISTCOLLECTIONS._serialized_end=63
  _LISTCOLLECTIONSREPLY._serialized_start=65
  _LISTCOLLECTIONSREPLY._serialized_end=104
  _DROPCOLLECTION._serialized_start=106
  _DROPCOLLECTION._serialized_end=146
  _DROPCOLLECTIONREPLY._serialized_start=148
  _DROPCOLLECTIONREPLY._serialized_end=169
  _QUERY._serialized_start=171
  _QUERY._serialized_end=298
  _QUERYREPLY._serialized_start=300
  _QUERYREPLY._serialized_end=329
  _GETDOCUMENTVERSION._serialized_start=331
  _GETDOCUMENTVERSION._serialized_end=421
  _GETDOCUMENTVERSIONREPLY._serialized_start=423
  _GETDOCUMENTVERSIONREPLY._serialized_end=464
  _AGGREGATE._serialized_start=466
  _AGGREGATE._serialized_end=552
  _AGGREGATEREPLY._serialized_start=554
  _AGGREGATEREPLY._serialized_end=587
  _COUNT._serialized_start=589
  _COUNT._serialized_end=652
  _COUNTREPLY._serialized_start=654
  _COUNTREPLY._serialized_end=682
  _INSERTONE._serialized_start=684
  _INSERTONE._serialized_end=755
  _INSERTONEREPLY._serialized_start=757
  _INSERTONEREPLY._serialized_end=789
  _INSERTMANY._serialized_start=791
  _INSERTMANY._serialized_end=885
  _INSERTMANYREPLY._serialized_start=887
  _INSERTMANYREPLY._serialized_end=921
  _UPDATEONE._serialized_start=923
  _UPDATEONE._serialized_end=994
  _UPDATEONEREPLY._serialized_start=996
  _UPDATEONEREPLY._serialized_end=1028
  _UPDATEDOCUMENT._serialized_start=1030
  _UPDATEDOCUMENT._serialized_end=1125
  _UPDATERESULT._serialized_start=1127
  _UPDATERESULT._serialized_end=1251
  _UPDATEDOCUMENTREPLY._serialized_start=1253
  _UPDATEDOCUMENTREPLY._serialized_end=1315
  _INSERTORUPDATEONE._serialized_start=1317
  _INSERTORUPDATEONE._serialized_end=1415
  _INSERTORUPDATEONEREPLY._serialized_start=1417
  _INSERTORUPDATEONEREPLY._serialized_end=1457
  _INSERTORUPDATEMANY._serialized_start=1459
  _INSERTORUPDATEMANY._serialized_end=1580
  _INSERTORUPDATEMANYREPLY._serialized_start=1582
  _INSERTORUPDATEMANYREPLY._serialized_end=1624
  _DELETEONE._serialized_start=1626
  _DELETEONE._serialized_end=1692
  _DELETEONEREPLY._serialized_start=1694
  _DELETEONEREPLY._serialized_end=1732
  _DELETEMANY._serialized_start=1734
  _DELETEMANY._serialized_end=1817
  _DELETEMANYREPLY._serialized_start=1819
  _DELETEMANYREPLY._serialized_end=1858
# @@protoc_insertion_point(module_scope)
