# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: watch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bwatch.proto\x12\x07openiap\".\n\x05watch\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\"\x18\n\nwatchreply\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\nwatchevent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\"\x15\n\x07unwatch\x12\n\n\x02id\x18\x01 \x01(\t\"\x0e\n\x0cunwatchreplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'watch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WATCH._serialized_start=24
  _WATCH._serialized_end=70
  _WATCHREPLY._serialized_start=72
  _WATCHREPLY._serialized_end=96
  _WATCHEVENT._serialized_start=98
  _WATCHEVENT._serialized_end=159
  _UNWATCH._serialized_start=161
  _UNWATCH._serialized_end=182
  _UNWATCHREPLY._serialized_start=184
  _UNWATCHREPLY._serialized_end=198
# @@protoc_insertion_point(module_scope)
